==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamiento no disponible",
    "Storage invalid" : "Almacenamiento inválido",
    "Unknown error" : "Error desconocido",
    "Could not move %s - File with this name already exists" : "No se pudo mover %s - Ya existe un archivo con ese nombre.",
    "Could not move %s" : "No se pudo mover %s",
    "Permission denied" : "Permiso denegado",
    "The target folder has been moved or deleted." : "La carpeta de destino fue movida o eliminada.",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nombre %s ya está en uso por la carpeta %s. Por favor elija uno diferente.",
    "Error when creating the file" : "Error al crear el archivo",
    "Error when creating the folder" : "Error al crear la carpeta.",
    "Unable to set upload directory." : "Incapaz de crear directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "No se subió ningún archivo. Error desconocido",
    "There is no error, the file uploaded with success" : "No hubo ningún problema, el archivo se subió con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo subido sobrepasa la directiva 'upload_max_filesize' en php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa la directiva 'MAX_FILE_SIZE' especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo cargado sólo se ha subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo",
    "Missing a temporary folder" : "Falta la carpeta temporal",
    "Failed to write to disk" : "Falló al escribir al disco",
    "Not enough storage available" : "No hay suficiente espacio disponible",
    "Upload failed. Could not find uploaded file" : "Actualización fallida. No se pudo encontrar el archivo subido",
    "Upload failed. Could not get file info." : "Actualización fallida. No se pudo obtener información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Files" : "Archivos",
    "All files" : "Todos los archivos",
    "Favorites" : "Favoritos",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamaño total del archivo {size1} excede el límite {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Upload cancelled." : "Subida cancelada.",
    "Could not get result from server." : "No se pudo obtener respuesta del servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Delete" : "Eliminar",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se pudo determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contáctese con el administrador",
    "Error moving file." : "Error al mover el archivo.",
    "Error moving file" : "Error moviendo archivo",
    "Error" : "Error",
    "{new_name} already exists" : "{new_name} ya existe",
    "Could not rename file" : "No se pudo renombrar el archivo",
    "Could not create file" : "No se pudo crear el archivo",
    "Could not create folder" : "No se pudo crear la carpeta",
    "Error deleting file." : "Error al borrar el archivo",
    "No entries in this folder match '{filter}'" : "No hay resultados que coincidan con '{filter}'",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El almacén de {owner} está repleto, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El almacén de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a Favoritos",
    "Favorite" : "Favorito",
    "{newname} already exists" : "{new_name} ya existe",
    "Upload" : "Subir",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaiones acerca de la creación y cambios de sus <strong>archivos favoritos</strong><em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Se ha <strong>eliminado</strong> un archivo o carpeta",
    "A file or folder has been <strong>restored</strong>" : "Se ha <strong>restaurado</strong> un archivo o carpeta",
    "You created %1$s" : "Ha creado %1$s",
    "%2$s created %1$s" : "%2$s ha creado %1$s",
    "%1$s was created in a public folder" : "%1$s ha sido creado en una carpeta pública",
    "You changed %1$s" : "Ha modificado %1$s",
    "%2$s changed %1$s" : "%2$s ha modificado %1$s",
    "You deleted %1$s" : "Ha eliminado %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminado %1$s",
    "You restored %1$s" : "Usted restauró %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "Changed by %2$s" : "Cambiado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "%s could not be renamed as it has been deleted" : "%s no se pudo renombrar pues ha sido eliminado",
    "%s could not be renamed" : "%s no pudo ser renombrado",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Con PHP-FPM este valor se puede demorar hasta 5 minutos para tener efecto después de guardar.",
    "Save" : "Guardar",
    "Can not be edited from here due to insufficient permissions." : "No se puede editar desde aquí por permisos insuficientes.",
    "Settings" : "Ajustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use esta URL <a href=\"%s\" target=\"_blank\">para acceder via WebDAV</a>",
    "Cancel upload" : "Cancelar la subida",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "Suba contenidos o sincronice sus dispositivos.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "Files are being scanned, please wait." : "Los archivos se están escaneando, por favor espere.",
    "Currently scanning" : "Escaneando en este momento",
    "No favorites" : "No hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que usted marque como favoritos"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamiento no disponible",
    "Storage invalid" : "Almacenamiento inválido",
    "Unknown error" : "Error desconocido",
    "Unable to set upload directory." : "Incapaz de crear directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "No se subió ningún archivo. Error desconocido",
    "There is no error, the file uploaded with success" : "No hubo ningún problema, el archivo se subió con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo subido sobrepasa la directiva 'upload_max_filesize' en php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa la directiva 'MAX_FILE_SIZE' especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo cargado sólo se ha subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo",
    "Missing a temporary folder" : "Falta la carpeta temporal",
    "Failed to write to disk" : "Falló al escribir al disco",
    "Not enough storage available" : "No hay suficiente espacio disponible",
    "The target folder has been moved or deleted." : "La carpeta de destino fue movida o eliminada.",
    "Upload failed. Could not find uploaded file" : "Actualización fallida. No se pudo encontrar el archivo subido",
    "Upload failed. Could not get file info." : "Actualización fallida. No se pudo obtener información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Files" : "Archivos",
    "All files" : "Todos los archivos",
    "File could not be found" : "El archivo no se ha encontrado",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "Subida cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamaño total del archivo {size1} excede el límite {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Error subiendo el archivo \"{fileName}\": {message}",
    "Could not get result from server." : "No se pudo obtener respuesta del servidor.",
    "Uploading..." : "Subiendo...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} hora{plural_s} pendiente",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuto{plural_s} pendiente",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} segundo{plural_s} pendiente",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momento...",
    "Soon..." : "Dentro de poco...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Unshare" : "Dejar de compartir",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contáctese con el administrador",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", destino ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya se utiliza en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "No se pudo crear la carpeta \"{dir}\" porque ya existe",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "No hay resultados que coincidan con '{filter}'",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El almacén de {owner} está repleto, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El almacén de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a Favoritos",
    "Favorite" : "Favorito",
    "Local link" : "Enlace local",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "{newname} already exists" : "{newname} ya existe",
    "Upload" : "Subir",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaiones acerca de la creación y cambios de sus <strong>archivos favoritos</strong><em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Se ha <strong>eliminado</strong> un archivo o carpeta",
    "A file or folder has been <strong>restored</strong>" : "Se ha <strong>restaurado</strong> un archivo o carpeta",
    "You created %1$s" : "Ha creado %1$s",
    "%2$s created %1$s" : "%2$s ha creado %1$s",
    "%1$s was created in a public folder" : "%1$s ha sido creado en una carpeta pública",
    "You changed %1$s" : "Ha modificado %1$s",
    "%2$s changed %1$s" : "%2$s ha modificado %1$s",
    "You deleted %1$s" : "Ha eliminado %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminado %1$s",
    "You restored %1$s" : "Usted restauró %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "Changed by %2$s" : "Cambiado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar 5 minutos para que se realicen los cambios.",
    "Missing permissions to edit from here." : "Faltan permisos para poder editar desde aquí.",
    "Settings" : "Ajustes",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Introduce esta dirección <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> en el cliente de ownCloud para acceder a tus archivos a través de él</a>",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "Suba contenidos o sincronice sus dispositivos.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "No favorites" : "No hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que usted marque como favoritos",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt"
},
"nplurals=2; plural=(n != 1);");
